@@ -45,8 +45,6 @@
 #    #
 ###
 
-from __future__ import division
-
 import supybot
 
 import re
@@ -224,7 +222,7 @@ class Nickometer(callbacks.Plugin):
 
         # Use an appropriate function to map [0, +inf) to [0, 100)
         percentage = 100 * (1 + math.tanh((score - 400.0) / 400.0)) * \
-                     (1 - 1 / (1 + score / 5.0)) // 2
+                     (1 - 1 / (1 + score / 5.0)) / 2
 
         # if it's above 99.9%, show as many digits as is interesting
         score_string=re.sub('(99\\.9*\\d|\\.\\d).*','\\1',repr(percentage))
