@@ -1062,7 +1062,8 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
     REQUEST_CAPABILITIES = set(['account-notify', 'extended-join',
         'multi-prefix', 'metadata-notify', 'account-tag',
         'userhost-in-names', 'invite-notify', 'server-time',
-        'chghost', 'batch', 'away-notify', 'message-tags'])
+        'chghost', 'batch', 'away-notify', 'message-tags',
+        'msgid'])
 
     def _queueConnectMessages(self):
         if self.zombie:
