@@ -33,6 +33,7 @@ from supybot.test import *
 import sys
 import time
 import pickle
+import supybot.conf as conf
 import supybot.utils as utils
 from supybot.utils.structures import *
 import supybot.utils.minisix as minisix
@@ -357,6 +358,18 @@ class StrTest(SupyTestCase):
         L.append((3,))
         self.assertRaises(TypeError, utils.str.commaAndify, L)
 
+    def testCommaAndifyConfig(self):
+        f = utils.str.commaAndify
+        L = ['foo', 'bar']
+        with conf.supybot.reply.format.list.maximumItems.context(3):
+            self.assertEqual(f(L), 'foo and bar')
+            L.append('baz')
+            self.assertEqual(f(L), 'foo, bar, and baz')
+            L.append('qux')
+            self.assertEqual(f(L), 'foo, bar, and 2 others')
+            L.append('quux')
+            self.assertEqual(f(L), 'foo, bar, and 3 others')
+
     def testUnCommaThe(self):
         f = utils.str.unCommaThe
         self.assertEqual(f('foo bar'), 'foo bar')
@@ -1110,7 +1123,7 @@ class TestTimeoutQueue(SupyTestCase):
         q.enqueue(3)
         self.assertEqual(len(q), 3)
         self.assertEqual(sum(q), 6)
-        time.sleep(1.1)
+        timeFastForward(1.1)
         self.assertEqual(len(q), 0)
         self.assertEqual(sum(q), 0)
 
@@ -1123,7 +1136,7 @@ class TestTimeoutQueue(SupyTestCase):
         q.enqueue(3)
         self.assertEqual(len(q), 3)
         self.assertEqual(sum(q), 6)
-        time.sleep(1.1)
+        timeFastForward(1.1)
         self.assertEqual(len(q), 0)
         self.assertEqual(sum(q), 0)
 
@@ -1133,7 +1146,7 @@ class TestTimeoutQueue(SupyTestCase):
         self.failUnless(1 in q)
         self.failUnless(1 in q) # For some reason, the second one might fail.
         self.failIf(2 in q)
-        time.sleep(1.1)
+        timeFastForward(1.1)
         self.failIf(1 in q)
 
     def testReset(self):
